@@ -117,7 +117,7 @@ def type(ctx):  # noqa: A001
     """🦆 Type-check sources with mypy."""
     _setup_environment(ctx)
     _run_check_commands(
-        ["stubtest", "mpi4py"],
+        ["stubtest", "--ignore-disjoint-bases", "mpi4py"],
         ["mypy", "-p", "mpi4py"],
     )
 
