@@ -1,6 +1,6 @@
 #!/bin/sh
 set -eu
-topdir=$(cd $(dirname "$0")/.. && pwd)
+topdir=$(cd "$(dirname "$0")"/.. && pwd)
 python "$topdir/conf/cythonize.py" \
-    --working "$topdir" $@ \
+    --working "$topdir" "$@" \
     "src/mpi4py/MPI.pyx"
