@@ -1,8 +1,10 @@
+from importlib import import_module
 from os import environ
 from warnings import catch_warnings
+
 from mpi4py import rc
 
-ATTRS = {a for a in dir(rc) if not a.startswith('_')}
+ATTRS = {a for a in dir(rc) if not a.startswith("_")}
 VALUE = -123456789
 
 for attr in ATTRS:
@@ -10,9 +12,9 @@ for attr in ATTRS:
     setattr(rc, attr, VALUE)
 
 with catch_warnings(record=True) as warnings:
-    from mpi4py import MPI
+    import_module("mpi4py.MPI")
 
 template = "mpi4py.rc.{}: unexpected value {}"
 expected = sorted({template.format(attr, repr(VALUE)) for attr in ATTRS})
 messages = sorted({str(entry.message) for entry in warnings})
-assert messages == expected,  "\n" + "\n".join(messages)
+assert messages == expected, "\n" + "\n".join(messages)
