@@ -7,7 +7,7 @@
 #ifndef MPI_REAL2
 #undef PyMPI_HAVE_MPI_REAL2
 #endif
-#ifndef MPI_MPI_COMPLEX4
+#ifndef MPI_COMPLEX4
 #undef PyMPI_HAVE_MPI_COMPLEX4
 #endif
 
@@ -15,7 +15,7 @@
 /* https://github.com/pmodels/mpich/issues/7278 */
 #if MPICH_NUMVERSION < 40300000
 #ifndef ROMIO_VERSION
-#include "mpi-io.h"
+#include "mpiio.h"
 #endif
 #endif
 
