@@ -1,13 +1,12 @@
 #ifndef PyMPI_CONFIG_MSMPI_H
 #define PyMPI_CONFIG_MSMPI_H
 
-#include "mpi-11.h"
-#include "mpi-12.h"
-#include "mpi-20.h"
-#include "mpi-22.h"
-#include "mpi-30.h"
-#include "mpi-31.h"
-#include "mpi-40.h"
+#include "mpiapi.h"
+
+#if MSMPI_VER == 0x100
+#undef  MSMPI_VER
+#define MSMPI_VER 0xA00
+#endif
 
 #if MSMPI_VER >= 0x402
 #define PyMPI_HAVE_MPI_AINT 1
