@@ -1,6 +1,9 @@
 /* Author:  Lisandro Dalcin   */
 /* Contact: dalcinl@gmail.com */
 
+#include <stdio.h>
+#include <string.h>
+
 static int PyMPI_Get_vendor(const char **vendor_name,
                             int         *version_major,
                             int         *version_minor,
@@ -9,7 +12,39 @@ static int PyMPI_Get_vendor(const char **vendor_name,
   const char *name = "unknown";
   int major=0, minor=0, micro=0;
 
-#if defined(I_MPI_VERSION)
+#if defined(MPI_ABI_VERSION) || defined(PYMPIABI)
+
+  int ierr, len = 0, cnt;
+  char lib[MPI_MAX_LIBRARY_VERSION_STRING] = {0}, *str;
+
+  ierr = MPI_Get_library_version(lib, &len);
+  if (ierr != MPI_SUCCESS) return ierr;
+
+  cnt = sscanf(lib, "MPICH Version: %d.%d.%d", &major, &minor, &micro);
+  if (cnt > 0) { name = "MPICH"; goto done; }
+
+  cnt = sscanf(lib, "Open MPI v%d.%d.%d", &major, &minor, &micro);
+  if (cnt > 0) { name = "Open MPI"; goto done; }
+
+  cnt = sscanf(lib, "Intel(R) MPI Library %d.%d.%d", &major, &minor, &micro);
+  if (cnt > 0) { name = "Intel MPI"; goto done; }
+
+  cnt = sscanf(lib, "Microsoft MPI %d.%d", &major, &minor);
+  if (cnt > 0) { name = "Microsoft MPI"; goto done; }
+
+  str = strstr(lib, "CRAY MPICH version"); if (!str) str = lib;
+  cnt = sscanf(str, "CRAY MPICH version %d.%d.%d", &major, &minor, &micro);
+  if (cnt > 0) { name = "Cray MPICH"; goto done; }
+
+  cnt = sscanf(lib, "MVAPICH Version: %d.%d.%d", &major, &minor, &micro);
+  if (cnt > 0) { name = "MVAPICH"; goto done; }
+
+  cnt = sscanf(lib, "MVAPICH2 Version: %d.%d.%d", &major, &minor, &micro);
+  if (cnt > 0) { name = "MVAPICH"; goto done; }
+
+ done:
+
+#elif defined(I_MPI_VERSION)
 
   name = "Intel MPI";
   #if defined(I_MPI_NUMVERSION)
@@ -21,20 +56,21 @@ static int PyMPI_Get_vendor(const char **vendor_name,
   (void)sscanf(I_MPI_VERSION,"%d.%d Update %d",&major,&minor,&micro);
   #endif
 
-#elif defined(PLATFORM_MPI)
-
-  name = "Platform MPI";
-  major = (PLATFORM_MPI>>24)&0xff;
-  minor = (PLATFORM_MPI>>16)&0xff;
-  micro = (PLATFORM_MPI>> 8)&0xff;
-  major = (major/16)*10+(major%16);
-
 #elif defined(MSMPI_VER)
 
   name = "Microsoft MPI";
   major = MSMPI_VER >> 8;
   minor = MSMPI_VER & 0xFF;
 
+#elif defined(CRAY_MPICH_VERSION)
+
+  name = "Cray MPICH";
+# define str(s) #s
+# define xstr(s) str(s)
+  (void)sscanf(xstr(CRAY_MPICH_VERSION),"%d.%d.%d",&major,&minor,&micro);
+# undef xstr
+# undef str
+
 #elif defined(MVAPICH_VERSION) || defined(MVAPICH_NUMVERSION)
 
   name = "MVAPICH";
@@ -49,7 +85,7 @@ static int PyMPI_Get_vendor(const char **vendor_name,
 
 #elif defined(MVAPICH2_VERSION) || defined(MVAPICH2_NUMVERSION)
 
-  name = "MVAPICH2";
+  name = "MVAPICH";
   #if defined(MVAPICH2_NUMVERSION)
   {int version = MVAPICH2_NUMVERSION/1000; if (version<1000) version *= 100;
   major = version/10000; version -= major*10000;
@@ -103,25 +139,6 @@ static int PyMPI_Get_vendor(const char **vendor_name,
   micro = OMPI_RELEASE_VERSION;
   #endif
 
-  #if defined(OMPI_MAJOR_VERSION)
-  #if OMPI_MAJOR_VERSION >= 10
-  name = "Spectrum MPI";
-  #endif
-  #endif
-
-#elif defined(LAM_MPI)
-
-  name = "LAM/MPI";
-  #if defined(LAM_MAJOR_VERSION)
-  major = LAM_MAJOR_VERSION;
-  #endif
-  #if defined(LAM_MINOR_VERSION)
-  minor = LAM_MINOR_VERSION;
-  #endif
-  #if defined(LAM_RELEASE_VERSION)
-  micro = LAM_RELEASE_VERSION;
-  #endif
-
 #endif
 
   if (vendor_name)   *vendor_name   = name;
@@ -129,12 +146,5 @@ static int PyMPI_Get_vendor(const char **vendor_name,
   if (version_minor) *version_minor = minor;
   if (version_micro) *version_micro = micro;
 
-  return 0;
+  return MPI_SUCCESS;
 }
-
-/*
-   Local variables:
-   c-basic-offset: 2
-   indent-tabs-mode: nil
-   End:
-*/
