@@ -1,6 +1,7 @@
-from mpi4py import MPI
-import mpiunittest as unittest
 import arrayimpl
+import mpiunittest as unittest
+
+from mpi4py import MPI
 
 
 def maxvalue(a):
@@ -8,9 +9,9 @@ def maxvalue(a):
         typecode = a.typecode
     except AttributeError:
         typecode = a.dtype.char
-    if typecode == ('f'):
+    if typecode == ("f"):
         return 1e30
-    elif typecode == ('d'):
+    elif typecode == ("d"):
         return 1e300
     else:
         return 2 ** (a.itemsize * 7) - 1
@@ -23,7 +24,7 @@ def StartWaitFree(request):
 
 
 class BaseTestCCOVec:
-
+    #
     COMM = MPI.COMM_NULL
 
     def testGatherv(self):
@@ -35,17 +36,18 @@ class BaseTestCCOVec:
                 check_b = arrayimpl.scalar(-1)
                 for count in range(size):
                     sbuf = array(root, typecode, count)
-                    rbuf = array(  -1, typecode, size*size)
+                    rbuf = array(-1, typecode, size * size)
                     counts = [count] * size
-                    displs = list(range(0, size*size, size))
+                    displs = list(range(0, size * size, size))
                     recvbuf = rbuf.as_mpi_v(counts, displs)
-                    if rank != root: recvbuf=None
+                    if rank != root:
+                        recvbuf = None
                     StartWaitFree(
-                    self.COMM.Gatherv_init(sbuf.as_mpi(), recvbuf, root)
+                        self.COMM.Gatherv_init(sbuf.as_mpi(), recvbuf, root)
                     )
                     if recvbuf is not None:
                         for i in range(size):
-                            row = rbuf[i*size:(i+1)*size]
+                            row = rbuf[i * size : (i + 1) * size]
                             a, b = row[:count], row[count:]
                             for va in a:
                                 self.assertEqual(va, check_a)
@@ -61,16 +63,17 @@ class BaseTestCCOVec:
                 check_b = arrayimpl.scalar(-1)
                 for count in range(size):
                     sbuf = array(root, typecode, size)
-                    rbuf = array(  -1, typecode, size*size)
+                    rbuf = array(-1, typecode, size * size)
                     sendbuf = sbuf.as_mpi_c(count)
                     recvbuf = rbuf.as_mpi_v(count, size)
-                    if rank != root: recvbuf=None
+                    if rank != root:
+                        recvbuf = None
                     StartWaitFree(
-                    self.COMM.Gatherv_init(sendbuf, recvbuf, root)
+                        self.COMM.Gatherv_init(sendbuf, recvbuf, root)
                     )
                     if recvbuf is not None:
                         for i in range(size):
-                            row = rbuf[i*size:(i+1)*size]
+                            row = rbuf[i * size : (i + 1) * size]
                             a, b = row[:count], row[count:]
                             for va in a:
                                 self.assertEqual(va, check_a)
@@ -83,15 +86,16 @@ class BaseTestCCOVec:
         for array, typecode in arrayimpl.loop():
             for root in range(size):
                 check = arrayimpl.scalar(root)
-                for count in range(size+1):
+                for count in range(size + 1):
                     #
                     sbuf = array(root, typecode, count).as_raw()
-                    rbuf = array(  -1, typecode, count*size).as_raw()
+                    rbuf = array(-1, typecode, count * size).as_raw()
                     sendbuf = sbuf
                     recvbuf = [rbuf, count]
-                    if rank != root: recvbuf=None
+                    if rank != root:
+                        recvbuf = None
                     StartWaitFree(
-                    self.COMM.Gatherv_init(sendbuf, recvbuf, root)
+                        self.COMM.Gatherv_init(sendbuf, recvbuf, root)
                     )
                     if recvbuf is not None:
                         for v in rbuf:
@@ -99,12 +103,10 @@ class BaseTestCCOVec:
                     #
                     sbuf = array(root, typecode, count).as_raw()
                     if rank == root:
-                        rbuf = array(  -1, typecode, count*size).as_raw()
+                        rbuf = array(-1, typecode, count * size).as_raw()
                     else:
                         rbuf = None
-                    StartWaitFree(
-                    self.COMM.Gatherv_init(sbuf, rbuf, root)
-                    )
+                    StartWaitFree(self.COMM.Gatherv_init(sbuf, rbuf, root))
                     if rank == root:
                         for v in rbuf:
                             self.assertEqual(v, check)
@@ -116,14 +118,15 @@ class BaseTestCCOVec:
             for root in range(size):
                 check = arrayimpl.scalar(root)
                 for count in range(size):
-                    sbuf = array(root, typecode, size*size)
-                    rbuf = array(  -1, typecode, count)
+                    sbuf = array(root, typecode, size * size)
+                    rbuf = array(-1, typecode, count)
                     counts = [count] * size
-                    displs = list(range(0, size*size, size))
+                    displs = list(range(0, size * size, size))
                     sendbuf = sbuf.as_mpi_v(counts, displs)
-                    if rank != root: sendbuf = None
+                    if rank != root:
+                        sendbuf = None
                     StartWaitFree(
-                    self.COMM.Scatterv_init(sendbuf, rbuf.as_mpi(), root)
+                        self.COMM.Scatterv_init(sendbuf, rbuf.as_mpi(), root)
                     )
                     for vr in rbuf:
                         self.assertEqual(vr, check)
@@ -136,13 +139,14 @@ class BaseTestCCOVec:
                 check_a = arrayimpl.scalar(root)
                 check_b = arrayimpl.scalar(-1)
                 for count in range(size):
-                    sbuf = array(root, typecode, size*size)
-                    rbuf = array(  -1, typecode, size)
+                    sbuf = array(root, typecode, size * size)
+                    rbuf = array(-1, typecode, size)
                     sendbuf = sbuf.as_mpi_v(count, size)
                     recvbuf = rbuf.as_mpi_c(count)
-                    if rank != root: sendbuf = None
+                    if rank != root:
+                        sendbuf = None
                     StartWaitFree(
-                    self.COMM.Scatterv_init(sendbuf, recvbuf, root)
+                        self.COMM.Scatterv_init(sendbuf, recvbuf, root)
                     )
                     a, b = rbuf[:count], rbuf[count:]
                     for va in a:
@@ -156,49 +160,46 @@ class BaseTestCCOVec:
         for array, typecode in arrayimpl.loop():
             for root in range(size):
                 check = arrayimpl.scalar(root)
-                for count in range(size+1):
+                for count in range(size + 1):
                     #
-                    sbuf = array(root, typecode, count*size).as_raw()
-                    rbuf = array(  -1, typecode, count).as_raw()
+                    sbuf = array(root, typecode, count * size).as_raw()
+                    rbuf = array(-1, typecode, count).as_raw()
                     sendbuf = [sbuf, count]
                     recvbuf = rbuf
-                    if rank != root: sendbuf = None
+                    if rank != root:
+                        sendbuf = None
                     StartWaitFree(
-                    self.COMM.Scatterv_init(sendbuf, recvbuf, root)
+                        self.COMM.Scatterv_init(sendbuf, recvbuf, root)
                     )
                     for v in rbuf:
                         self.assertEqual(v, check)
                     #
                     if rank == root:
-                        sbuf = array(root, typecode, count*size).as_raw()
+                        sbuf = array(root, typecode, count * size).as_raw()
                     else:
                         sbuf = None
-                    rbuf = array(  -1, typecode, count).as_raw()
-                    StartWaitFree(
-                    self.COMM.Scatterv_init(sbuf, rbuf, root)
-                    )
+                    rbuf = array(-1, typecode, count).as_raw()
+                    StartWaitFree(self.COMM.Scatterv_init(sbuf, rbuf, root))
                     for v in rbuf:
                         self.assertEqual(v, check)
 
     def testAllgatherv(self):
         size = self.COMM.Get_size()
-        rank = self.COMM.Get_rank()
+        self.COMM.Get_rank()
         for array, typecode in arrayimpl.loop():
             for root in range(size):
                 check_a = arrayimpl.scalar(root)
                 check_b = arrayimpl.scalar(-1)
                 for count in range(size):
                     sbuf = array(root, typecode, count)
-                    rbuf = array(  -1, typecode, size*size)
+                    rbuf = array(-1, typecode, size * size)
                     counts = [count] * size
-                    displs = list(range(0, size*size, size))
+                    displs = list(range(0, size * size, size))
                     sendbuf = sbuf.as_mpi()
                     recvbuf = rbuf.as_mpi_v(counts, displs)
-                    StartWaitFree(
-                    self.COMM.Allgatherv_init(sendbuf, recvbuf)
-                    )
+                    StartWaitFree(self.COMM.Allgatherv_init(sendbuf, recvbuf))
                     for i in range(size):
-                        row = rbuf[i*size:(i+1)*size]
+                        row = rbuf[i * size : (i + 1) * size]
                         a, b = row[:count], row[count:]
                         for va in a:
                             self.assertEqual(va, check_a)
@@ -207,21 +208,19 @@ class BaseTestCCOVec:
 
     def testAllgatherv2(self):
         size = self.COMM.Get_size()
-        rank = self.COMM.Get_rank()
+        self.COMM.Get_rank()
         for array, typecode in arrayimpl.loop():
             for root in range(size):
                 check_a = arrayimpl.scalar(root)
                 check_b = arrayimpl.scalar(-1)
                 for count in range(size):
                     sbuf = array(root, typecode, size)
-                    rbuf = array(  -1, typecode, size*size)
+                    rbuf = array(-1, typecode, size * size)
                     sendbuf = sbuf.as_mpi_c(count)
                     recvbuf = rbuf.as_mpi_v(count, size)
-                    StartWaitFree(
-                    self.COMM.Allgatherv_init(sendbuf, recvbuf)
-                    )
+                    StartWaitFree(self.COMM.Allgatherv_init(sendbuf, recvbuf))
                     for i in range(size):
-                        row = rbuf[i*size:(i+1)*size]
+                        row = rbuf[i * size : (i + 1) * size]
                         a, b = row[:count], row[count:]
                         for va in a:
                             self.assertEqual(va, check_a)
@@ -230,47 +229,43 @@ class BaseTestCCOVec:
 
     def testAllgatherv3(self):
         size = self.COMM.Get_size()
-        rank = self.COMM.Get_rank()
+        self.COMM.Get_rank()
         for array, typecode in arrayimpl.loop():
             for root in range(size):
                 check = arrayimpl.scalar(root)
-                for count in range(size+1):
+                for count in range(size + 1):
                     #
                     sbuf = array(root, typecode, count).as_raw()
-                    rbuf = array(  -1, typecode, count*size).as_raw()
+                    rbuf = array(-1, typecode, count * size).as_raw()
                     sendbuf = sbuf
                     recvbuf = [rbuf, count]
-                    StartWaitFree(
-                    self.COMM.Allgatherv_init(sendbuf, recvbuf)
-                    )
+                    StartWaitFree(self.COMM.Allgatherv_init(sendbuf, recvbuf))
                     for v in rbuf:
                         self.assertEqual(v, check)
                     #
                     sbuf = array(root, typecode, count).as_raw()
-                    rbuf = array(  -1, typecode, count*size).as_raw()
+                    rbuf = array(-1, typecode, count * size).as_raw()
                     self.COMM.Allgatherv(sbuf, rbuf)
                     for v in rbuf:
                         self.assertEqual(v, check)
 
     def testAlltoallv(self):
         size = self.COMM.Get_size()
-        rank = self.COMM.Get_rank()
+        self.COMM.Get_rank()
         for array, typecode in arrayimpl.loop():
             for root in range(size):
                 check_a = arrayimpl.scalar(root)
                 check_b = arrayimpl.scalar(-1)
                 for count in range(size):
-                    sbuf = array(root, typecode, size*size)
-                    rbuf = array(  -1, typecode, size*size)
+                    sbuf = array(root, typecode, size * size)
+                    rbuf = array(-1, typecode, size * size)
                     counts = [count] * size
-                    displs = list(range(0, size*size, size))
+                    displs = list(range(0, size * size, size))
                     sendbuf = sbuf.as_mpi_v(counts, displs)
                     recvbuf = rbuf.as_mpi_v(counts, displs)
-                    StartWaitFree(
-                    self.COMM.Alltoallv_init(sendbuf, recvbuf)
-                    )
+                    StartWaitFree(self.COMM.Alltoallv_init(sendbuf, recvbuf))
                     for i in range(size):
-                        row = rbuf[i*size:(i+1)*size]
+                        row = rbuf[i * size : (i + 1) * size]
                         a, b = row[:count], row[count:]
                         for va in a:
                             self.assertEqual(va, check_a)
@@ -279,21 +274,19 @@ class BaseTestCCOVec:
 
     def testAlltoallv2(self):
         size = self.COMM.Get_size()
-        rank = self.COMM.Get_rank()
+        self.COMM.Get_rank()
         for array, typecode in arrayimpl.loop():
             for root in range(size):
                 check_a = arrayimpl.scalar(root)
                 check_b = arrayimpl.scalar(-1)
                 for count in range(size):
-                    sbuf = array(root, typecode, size*size)
-                    rbuf = array(  -1, typecode, size*size)
+                    sbuf = array(root, typecode, size * size)
+                    rbuf = array(-1, typecode, size * size)
                     sendbuf = sbuf.as_mpi_v(count, size)
                     recvbuf = rbuf.as_mpi_v(count, size)
-                    StartWaitFree(
-                    self.COMM.Alltoallv_init(sendbuf, recvbuf)
-                    )
+                    StartWaitFree(self.COMM.Alltoallv_init(sendbuf, recvbuf))
                     for i in range(size):
-                        row = rbuf[i*size:(i+1)*size]
+                        row = rbuf[i * size : (i + 1) * size]
                         a, b = row[:count], row[count:]
                         for va in a:
                             self.assertEqual(va, check_a)
@@ -302,85 +295,88 @@ class BaseTestCCOVec:
 
     def testAlltoallv3(self):
         size = self.COMM.Get_size()
-        rank = self.COMM.Get_rank()
+        self.COMM.Get_rank()
         for array, typecode in arrayimpl.loop():
             for root in range(size):
                 check = arrayimpl.scalar(root)
-                for count in range(size+1):
+                for count in range(size + 1):
                     #
-                    sbuf = array(root, typecode, count*size).as_raw()
-                    rbuf = array(  -1, typecode, count*size).as_raw()
+                    sbuf = array(root, typecode, count * size).as_raw()
+                    rbuf = array(-1, typecode, count * size).as_raw()
                     sendbuf = [sbuf, count]
                     recvbuf = [rbuf, count]
-                    StartWaitFree(
-                    self.COMM.Alltoallv_init(sendbuf, recvbuf)
-                    )
+                    StartWaitFree(self.COMM.Alltoallv_init(sendbuf, recvbuf))
                     for v in rbuf:
                         self.assertEqual(v, check)
                     #
-                    sbuf = array(root, typecode, count*size).as_raw()
-                    rbuf = array(  -1, typecode, count*size).as_raw()
-                    StartWaitFree(
-                    self.COMM.Alltoallv_init(sbuf, rbuf)
-                    )
+                    sbuf = array(root, typecode, count * size).as_raw()
+                    rbuf = array(-1, typecode, count * size).as_raw()
+                    StartWaitFree(self.COMM.Alltoallv_init(sbuf, rbuf))
                     for v in rbuf:
                         self.assertEqual(v, check)
 
     def testAlltoallw(self):
         size = self.COMM.Get_size()
-        rank = self.COMM.Get_rank()
+        self.COMM.Get_rank()
         for array, typecode in arrayimpl.loop():
-            for n in range(1, size+1):
+            for n in range(1, size + 1):
                 check = arrayimpl.scalar(n)
-                sbuf = array( n, typecode, (size, n))
+                sbuf = array(n, typecode, (size, n))
                 rbuf = array(-1, typecode, (size, n))
                 sdt, rdt = sbuf.mpidtype, rbuf.mpidtype
-                sdsp = list(range(0, size*n*sdt.extent, n*sdt.extent))
-                rdsp = list(range(0, size*n*rdt.extent, n*rdt.extent))
-                smsg = (sbuf.as_raw(), ([n]*size, sdsp), [sdt]*size)
-                rmsg = (rbuf.as_raw(), ([n]*size, rdsp), [rdt]*size)
-                StartWaitFree(
-                self.COMM.Alltoallw_init(smsg, rmsg)
-                )
+                sdsp = list(range(0, size * n * sdt.extent, n * sdt.extent))
+                rdsp = list(range(0, size * n * rdt.extent, n * rdt.extent))
+                smsg = (sbuf.as_raw(), ([n] * size, sdsp), [sdt] * size)
+                rmsg = (rbuf.as_raw(), ([n] * size, rdsp), [rdt] * size)
+                StartWaitFree(self.COMM.Alltoallw_init(smsg, rmsg))
                 for value in rbuf.flat:
                     self.assertEqual(value, check)
 
     def testAlltoallwBottom(self):
         size = self.COMM.Get_size()
-        rank = self.COMM.Get_rank()
+        self.COMM.Get_rank()
         for array, typecode in arrayimpl.loop():
-            for n in range(1, size+1):
+            for n in range(1, size + 1):
                 check = arrayimpl.scalar(n)
-                sbuf = array( n, typecode, (size, n))
+                sbuf = array(n, typecode, (size, n))
                 rbuf = array(-1, typecode, (size, n))
                 saddr = MPI.Get_address(sbuf.as_raw())
                 raddr = MPI.Get_address(rbuf.as_raw())
                 sdt, rdt = sbuf.mpidtype, rbuf.mpidtype
                 stypes = [
-                    MPI.Datatype.Create_struct([n], [saddr+d], [sdt]).Commit()
-                    for d in list(range(0, size*n*sdt.extent, n*sdt.extent))
+                    MPI.Datatype.Create_struct(
+                        [n], [saddr + d], [sdt]
+                    ).Commit()
+                    for d in list(
+                        range(0, size * n * sdt.extent, n * sdt.extent)
+                    )
                 ]
                 rtypes = [
-                    MPI.Datatype.Create_struct([n], [raddr+d], [sdt]).Commit()
-                    for d in list(range(0, size*n*rdt.extent, n*rdt.extent))
+                    MPI.Datatype.Create_struct(
+                        [n], [raddr + d], [sdt]
+                    ).Commit()
+                    for d in list(
+                        range(0, size * n * rdt.extent, n * rdt.extent)
+                    )
                 ]
-                smsg = (MPI.BOTTOM, ([1]*size, [0]*size), stypes)
-                rmsg = (MPI.BOTTOM, ([1]*size, [0]*size), rtypes)
+                smsg = (MPI.BOTTOM, ([1] * size, [0] * size), stypes)
+                rmsg = (MPI.BOTTOM, ([1] * size, [0] * size), rtypes)
                 try:
-                  StartWaitFree(
-	          self.COMM.Alltoallw_init(smsg, rmsg)
-                  )
+                    StartWaitFree(self.COMM.Alltoallw_init(smsg, rmsg))
                 finally:
-                    for t in stypes: t.Free()
-                    for t in rtypes: t.Free()
+                    for t in stypes:
+                        t.Free()
+                    for t in rtypes:
+                        t.Free()
                 for value in rbuf.flat:
                     self.assertEqual(value, check)
 
-@unittest.skipMPI('msmpi(<8.1.0)')
-@unittest.skipMPI('openmpi(<1.8.0)')
-@unittest.skipIf(MPI.BOTTOM == MPI.IN_PLACE, 'mpi-in-place')
-class BaseTestCCOVecInplace:
 
+@unittest.skipMPI("msmpi(<8.1.0)")
+@unittest.skipMPI("openmpi(<1.8.0)")
+@unittest.skipIf(MPI.BOTTOM == MPI.IN_PLACE, "mpi-in-place")
+class BaseTestCCOVecInplace:
+    #
     COMM = MPI.COMM_NULL
 
     def testAlltoallv(self):
@@ -388,18 +384,16 @@ class BaseTestCCOVecInplace:
         rank = self.COMM.Get_rank()
         for array, typecode in arrayimpl.loop():
             for count in range(size):
-                rbuf = array(-1, typecode, size*size)
+                rbuf = array(-1, typecode, size * size)
                 counts = [count] * size
-                displs = list(range(0, size*size, size))
+                displs = list(range(0, size * size, size))
                 for i in range(size):
                     for j in range(count):
-                        rbuf[i*size+j] = rank
+                        rbuf[i * size + j] = rank
                 recvbuf = rbuf.as_mpi_v(counts, displs)
-                StartWaitFree(
-                self.COMM.Alltoallv_init(MPI.IN_PLACE, recvbuf)
-                )
+                StartWaitFree(self.COMM.Alltoallv_init(MPI.IN_PLACE, recvbuf))
                 for i in range(size):
-                    row = rbuf[i*size:(i+1)*size]
+                    row = rbuf[i * size : (i + 1) * size]
                     a, b = row[:count], row[count:]
                     for va in a:
                         check_a = arrayimpl.scalar(i)
@@ -413,18 +407,18 @@ class BaseTestCCOVecInplace:
         rank = self.COMM.Get_rank()
         for array, typecode in arrayimpl.loop():
             for count in range(size):
-                rbuf = array(-1, typecode, size*size)
+                rbuf = array(-1, typecode, size * size)
                 for i in range(size):
                     for j in range(count):
-                        rbuf[i*size+j] = rank
+                        rbuf[i * size + j] = rank
                 rdt = rbuf.mpidtype
-                rdsp = list(range(0, size*size*rdt.extent, size*rdt.extent))
-                rmsg = (rbuf.as_raw(), ([count]*size, rdsp), [rdt]*size)
-                StartWaitFree(
-                self.COMM.Alltoallw_init(MPI.IN_PLACE, rmsg)
+                rdsp = list(
+                    range(0, size * size * rdt.extent, size * rdt.extent)
                 )
+                rmsg = (rbuf.as_raw(), ([count] * size, rdsp), [rdt] * size)
+                StartWaitFree(self.COMM.Alltoallw_init(MPI.IN_PLACE, rmsg))
                 for i in range(size):
-                    row = rbuf[i*size:(i+1)*size]
+                    row = rbuf[i * size : (i + 1) * size]
                     a, b = row[:count], row[count:]
                     for va in a:
                         check_a = arrayimpl.scalar(i)
@@ -438,18 +432,18 @@ class BaseTestCCOVecInplace:
         rank = self.COMM.Get_rank()
         for array, typecode in arrayimpl.loop():
             for count in range(size):
-                rbuf = array(-1, typecode, size*size)
+                rbuf = array(-1, typecode, size * size)
                 for i in range(size):
                     for j in range(count):
-                        rbuf[i*size+j] = rank
+                        rbuf[i * size + j] = rank
                 rdt = rbuf.mpidtype
-                rdsp = list(range(0, size*size*rdt.extent, size*rdt.extent))
-                rmsg = (rbuf.as_raw(), [count]*size, rdsp, [rdt]*size)
-                StartWaitFree(
-                self.COMM.Alltoallw_init(MPI.IN_PLACE, rmsg)
+                rdsp = list(
+                    range(0, size * size * rdt.extent, size * rdt.extent)
                 )
+                rmsg = (rbuf.as_raw(), [count] * size, rdsp, [rdt] * size)
+                StartWaitFree(self.COMM.Alltoallw_init(MPI.IN_PLACE, rmsg))
                 for i in range(size):
-                    row = rbuf[i*size:(i+1)*size]
+                    row = rbuf[i * size : (i + 1) * size]
                     a, b = row[:count], row[count:]
                     for va in a:
                         check_a = arrayimpl.scalar(i)
@@ -460,36 +454,49 @@ class BaseTestCCOVecInplace:
 
 
 class TestCCOVecSelf(BaseTestCCOVec, unittest.TestCase):
+    #
     COMM = MPI.COMM_SELF
 
+
 class TestCCOVecWorld(BaseTestCCOVec, unittest.TestCase):
+    #
     COMM = MPI.COMM_WORLD
 
+
 class TestCCOVecSelfDup(TestCCOVecSelf):
+    #
     def setUp(self):
         self.COMM = MPI.COMM_SELF.Dup()
+
     def tearDown(self):
         self.COMM.Free()
 
+
 class TestCCOVecWorldDup(TestCCOVecWorld):
+    #
     def setUp(self):
         self.COMM = MPI.COMM_WORLD.Dup()
+
     def tearDown(self):
         self.COMM.Free()
 
+
 class TestCCOVecInplaceSelf(BaseTestCCOVecInplace, unittest.TestCase):
+    #
     COMM = MPI.COMM_SELF
 
+
 class TestCCOVecInplaceWorld(BaseTestCCOVecInplace, unittest.TestCase):
+    #
     COMM = MPI.COMM_WORLD
 
 
 try:
-    StartWaitFree( MPI.COMM_SELF.Barrier_init() )
+    StartWaitFree(MPI.COMM_SELF.Barrier_init())
 except NotImplementedError:
-    unittest.disable(BaseTestCCOVec, 'mpi-coll-persist')
-    unittest.disable(BaseTestCCOVecInplace, 'mpi-coll-persist')
+    unittest.disable(BaseTestCCOVec, "mpi-coll-persist")
+    unittest.disable(BaseTestCCOVecInplace, "mpi-coll-persist")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
