@@ -1,7 +1,8 @@
-from mpi4py import MPI
 import mpiunittest as unittest
 
-# ------------------------------------------------------------------------------
+from mpi4py import MPI
+
+# -----------------------------------------------------------------------------
 
 _errclasscache = {}
 
@@ -9,17 +10,18 @@ _errclasscache = {}
 def ErrClassName(ierr):
     if not _errclasscache:
         from mpi4py import MPI
-        _errclasscache[MPI.SUCCESS] = 'SUCCESS'
+
+        _errclasscache[MPI.SUCCESS] = "SUCCESS"
         for entry in dir(MPI):
-            if entry.startswith('ERR_'):
+            if entry.startswith("ERR_"):
                 errcls = getattr(MPI, entry)
                 _errclasscache[errcls] = entry
-    return _errclasscache.get(ierr, '<unknown>')
+    return _errclasscache.get(ierr, "<unknown>")
 
 
-@unittest.skipMPI('MPICH2')
+@unittest.skipMPI("MPICH2")
 class BaseTestCase(unittest.TestCase):
-
+    #
     def setUp(self):
         self.errhdl_world = MPI.COMM_WORLD.Get_errhandler()
         MPI.COMM_WORLD.Set_errhandler(MPI.ERRORS_RETURN)
@@ -34,22 +36,23 @@ class BaseTestCase(unittest.TestCase):
 
     def assertRaisesMPI(self, IErrClass, callableObj, *args, **kwargs):
         from mpi4py import MPI
+
         excClass = MPI.Exception
         try:
             callableObj(*args, **kwargs)
         except NotImplementedError:
-            if (MPI.VERSION, MPI.SUBVERSION) < (2, 0):
-                raise self.failureException("raised NotImplementedError")
-            raise
+            if MPI.Get_version() >= (2, 0):
+                raise
+            raise self.failureException("raised NotImplementedError") from None
         except excClass as excValue:
             error_class = excValue.Get_error_class()
         else:
             error_class = None
         if error_class is not None:
             if isinstance(IErrClass, (list, tuple, set)):
-                match = (error_class in IErrClass)
+                match = error_class in IErrClass
             else:
-                match = (error_class == IErrClass)
+                match = error_class == IErrClass
             if not match:
                 if isinstance(IErrClass, (list, tuple, set)):
                     IErrClassName = [ErrClassName(e) for e in IErrClass]
@@ -65,10 +68,11 @@ class BaseTestCase(unittest.TestCase):
             raise self.failureException(f"{excClass.__name__} not raised")
 
 
-# ------------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
+
 
 class TestExcDatatypeNull(BaseTestCase):
-
+    #
     def testDup(self):
         self.assertRaisesMPI(
             MPI.ERR_TYPE,
@@ -87,27 +91,44 @@ class TestExcDatatypeNull(BaseTestCase):
             MPI.DATATYPE_NULL.Free,
         )
 
-class TestExcDatatype(BaseTestCase):
 
+class TestExcDatatype(BaseTestCase):
+    #
     DATATYPES = (
-        MPI.BYTE, MPI.PACKED,
-        MPI.CHAR, MPI.WCHAR,
-        MPI.SIGNED_CHAR,  MPI.UNSIGNED_CHAR,
-        MPI.SHORT,  MPI.UNSIGNED_SHORT,
-        MPI.INT,  MPI.UNSIGNED,  MPI.UNSIGNED_INT,
-        MPI.LONG,  MPI.UNSIGNED_LONG,
-        MPI.LONG_LONG, MPI.UNSIGNED_LONG_LONG,
-        MPI.FLOAT,  MPI.DOUBLE, MPI.LONG_DOUBLE,
-        MPI.SHORT_INT,  MPI.TWOINT,  MPI.INT_INT, MPI.LONG_INT,
-        MPI.FLOAT_INT,  MPI.DOUBLE_INT,  MPI.LONG_DOUBLE_INT,
+        MPI.BYTE,
+        MPI.PACKED,
+        MPI.CHAR,
+        MPI.WCHAR,
+        MPI.SIGNED_CHAR,
+        MPI.UNSIGNED_CHAR,
+        MPI.SHORT,
+        MPI.UNSIGNED_SHORT,
+        MPI.INT,
+        MPI.UNSIGNED,
+        MPI.UNSIGNED_INT,
+        MPI.LONG,
+        MPI.UNSIGNED_LONG,
+        MPI.LONG_LONG,
+        MPI.UNSIGNED_LONG_LONG,
+        MPI.FLOAT,
+        MPI.DOUBLE,
+        MPI.LONG_DOUBLE,
+        MPI.SHORT_INT,
+        MPI.TWOINT,
+        MPI.INT_INT,
+        MPI.LONG_INT,
+        MPI.FLOAT_INT,
+        MPI.DOUBLE_INT,
+        MPI.LONG_DOUBLE_INT,
     )
 
-    ERR_TYPE   = MPI.ERR_TYPE
+    ERR_TYPE = MPI.ERR_TYPE
 
-    @unittest.skipMPI('msmpi')
+    @unittest.skipMPI("msmpi")
     def testFreePredefined(self):
         for dtype in self.DATATYPES:
-            if dtype == MPI.DATATYPE_NULL: continue
+            if dtype == MPI.DATATYPE_NULL:
+                continue
             self.assertRaisesMPI(
                 self.ERR_TYPE,
                 dtype.Free,
@@ -116,52 +137,62 @@ class TestExcDatatype(BaseTestCase):
 
     def testKeyvalInvalid(self):
         for dtype in self.DATATYPES:
-            if dtype == MPI.DATATYPE_NULL: continue
+            if dtype == MPI.DATATYPE_NULL:
+                continue
             try:
                 self.assertRaisesMPI(
                     [MPI.ERR_KEYVAL, MPI.ERR_OTHER],
-                    dtype.Get_attr, MPI.KEYVAL_INVALID,
+                    dtype.Get_attr,
+                    MPI.KEYVAL_INVALID,
                 )
             except NotImplementedError:
-                self.skipTest('mpi-type-get_attr')
+                self.skipTest("mpi-type-get_attr")
+
 
 name, version = MPI.get_vendor()
-if name == 'Open MPI':
-    if version < (1,4,3):
+if name == "Open MPI":
+    if version < (1, 4, 3):
         TestExcDatatype.DATATYPES = TestExcDatatype.DATATYPES[1:]
-        TestExcDatatype.ERR_TYPE  = MPI.ERR_INTERN
+        TestExcDatatype.ERR_TYPE = MPI.ERR_INTERN
 
-# ------------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 
-@unittest.skipMPI('msmpi(<=4.2.0)')
+
+@unittest.skipMPI("msmpi(<=4.2.0)")
 class TestExcStatus(BaseTestCase):
-
+    #
     def testGetCount(self):
         status = MPI.Status()
         self.assertRaisesMPI(
             MPI.ERR_TYPE,
-            status.Get_count, MPI.DATATYPE_NULL,
+            status.Get_count,
+            MPI.DATATYPE_NULL,
         )
 
     def testGetElements(self):
         status = MPI.Status()
         self.assertRaisesMPI(
             MPI.ERR_TYPE,
-            status.Get_elements, MPI.DATATYPE_NULL,
+            status.Get_elements,
+            MPI.DATATYPE_NULL,
         )
 
-    @unittest.skipMPI('MPICH1')
+    @unittest.skipMPI("MPICH1")
     def testSetElements(self):
         status = MPI.Status()
         self.assertRaisesMPI(
             MPI.ERR_TYPE,
-            status.Set_elements, MPI.DATATYPE_NULL, 0,
+            status.Set_elements,
+            MPI.DATATYPE_NULL,
+            0,
         )
 
-# ------------------------------------------------------------------------------
+
+# -----------------------------------------------------------------------------
+
 
 class TestExcRequestNull(BaseTestCase):
-
+    #
     def testFree(self):
         self.assertRaisesMPI(
             MPI.ERR_REQUEST,
@@ -174,41 +205,54 @@ class TestExcRequestNull(BaseTestCase):
             MPI.REQUEST_NULL.Cancel,
         )
 
-# ------------------------------------------------------------------------------
+
+# -----------------------------------------------------------------------------
+
 
 class TestExcOpNull(BaseTestCase):
-
+    #
     def testFree(self):
         self.assertRaisesMPI(
             [MPI.ERR_OP, MPI.ERR_ARG],
             MPI.OP_NULL.Free,
         )
 
-class TestExcOp(BaseTestCase):
 
+class TestExcOp(BaseTestCase):
+    #
     OPS = (
-        MPI.MAX, MPI.MIN,
-        MPI.SUM, MPI.PROD,
-        MPI.LAND, MPI.BAND,
-        MPI.LOR, MPI.BOR,
-        MPI.LXOR, MPI.BXOR,
-        MPI.MAXLOC, MPI.MINLOC,
-        MPI.REPLACE, MPI.NO_OP,
+        MPI.MAX,
+        MPI.MIN,
+        MPI.SUM,
+        MPI.PROD,
+        MPI.LAND,
+        MPI.BAND,
+        MPI.LOR,
+        MPI.BOR,
+        MPI.LXOR,
+        MPI.BXOR,
+        MPI.MAXLOC,
+        MPI.MINLOC,
+        MPI.REPLACE,
+        MPI.NO_OP,
     )
 
     def testFreePredefined(self):
         for op in self.OPS:
-            if op == MPI.OP_NULL: continue
+            if op == MPI.OP_NULL:
+                continue
             self.assertRaisesMPI(
                 [MPI.ERR_OP, MPI.ERR_ARG],
                 op.Free,
             )
             self.assertNotEqual(op, MPI.OP_NULL)
 
-# ------------------------------------------------------------------------------
+
+# -----------------------------------------------------------------------------
+
 
 class TestExcInfoNull(BaseTestCase):
-
+    #
     def testFree(self):
         self.assertRaisesMPI(
             [MPI.ERR_INFO, MPI.ERR_ARG],
@@ -218,7 +262,7 @@ class TestExcInfoNull(BaseTestCase):
     def testTruth(self):
         self.assertFalse(bool(MPI.INFO_NULL))
 
-    @unittest.skipMPI('msmpi(<8.1.0)')
+    @unittest.skipMPI("msmpi(<8.1.0)")
     def testDup(self):
         self.assertRaisesMPI(
             [MPI.ERR_INFO, MPI.ERR_ARG],
@@ -228,19 +272,23 @@ class TestExcInfoNull(BaseTestCase):
     def testGet(self):
         self.assertRaisesMPI(
             [MPI.ERR_INFO, MPI.ERR_ARG],
-            MPI.INFO_NULL.Get, 'key',
+            MPI.INFO_NULL.Get,
+            "key",
         )
 
     def testSet(self):
         self.assertRaisesMPI(
             [MPI.ERR_INFO, MPI.ERR_ARG],
-            MPI.INFO_NULL.Set, 'key', 'value',
+            MPI.INFO_NULL.Set,
+            "key",
+            "value",
         )
 
     def testDelete(self):
         self.assertRaisesMPI(
             [MPI.ERR_INFO, MPI.ERR_ARG],
-            MPI.INFO_NULL.Delete, 'key',
+            MPI.INFO_NULL.Delete,
+            "key",
         )
 
     def testGetNKeys(self):
@@ -252,14 +300,16 @@ class TestExcInfoNull(BaseTestCase):
     def testGetNthKey(self):
         self.assertRaisesMPI(
             [MPI.ERR_INFO, MPI.ERR_ARG],
-            MPI.INFO_NULL.Get_nthkey, 0,
+            MPI.INFO_NULL.Get_nthkey,
+            0,
         )
 
-class TestExcInfo(BaseTestCase):
 
+class TestExcInfo(BaseTestCase):
+    #
     def setUp(self):
         super().setUp()
-        self.INFO  = MPI.Info.Create()
+        self.INFO = MPI.Info.Create()
 
     def tearDown(self):
         self.INFO.Free()
@@ -269,53 +319,67 @@ class TestExcInfo(BaseTestCase):
     def testDelete(self):
         self.assertRaisesMPI(
             MPI.ERR_INFO_NOKEY,
-            self.INFO.Delete, 'key',
+            self.INFO.Delete,
+            "key",
         )
 
     def testGetNthKey(self):
         self.assertRaisesMPI(
             [MPI.ERR_INFO_KEY, MPI.ERR_ARG],
-            self.INFO.Get_nthkey, 0,
+            self.INFO.Get_nthkey,
+            0,
         )
 
+
 try:
     MPI.Info.Create().Free()
 except NotImplementedError:
-    unittest.disable(TestExcInfo, 'mpi-info')
-    unittest.disable(TestExcInfoNull, 'mpi-info')
+    unittest.disable(TestExcInfo, "mpi-info")
+    unittest.disable(TestExcInfoNull, "mpi-info")
+
+# -----------------------------------------------------------------------------
 
-# ------------------------------------------------------------------------------
 
 class TestExcGroupNull(BaseTestCase):
-
+    #
     def testCompare(self):
         self.assertRaisesMPI(
             MPI.ERR_GROUP,
-            MPI.Group.Compare, MPI.GROUP_NULL,  MPI.GROUP_NULL,
+            MPI.Group.Compare,
+            MPI.GROUP_NULL,
+            MPI.GROUP_NULL,
         )
         self.assertRaisesMPI(
             MPI.ERR_GROUP,
-            MPI.Group.Compare, MPI.GROUP_NULL,  MPI.GROUP_EMPTY,
+            MPI.Group.Compare,
+            MPI.GROUP_NULL,
+            MPI.GROUP_EMPTY,
         )
         self.assertRaisesMPI(
             MPI.ERR_GROUP,
-            MPI.Group.Compare, MPI.GROUP_EMPTY, MPI.GROUP_NULL,
+            MPI.Group.Compare,
+            MPI.GROUP_EMPTY,
+            MPI.GROUP_NULL,
         )
 
     def testAccessors(self):
-        for method in ('Get_size', 'Get_rank'):
+        for method in ("Get_size", "Get_rank"):
             self.assertRaisesMPI(
                 MPI.ERR_GROUP,
                 getattr(MPI.GROUP_NULL, method),
             )
 
+
 class TestExcGroup(BaseTestCase):
+    #
     pass
 
-# ------------------------------------------------------------------------------
+
+# -----------------------------------------------------------------------------
+
 
 class TestExcSessionNull(BaseTestCase):
-
+    #
     def testGetNumPsets(self):
         self.assertRaisesMPI(
             MPI.ERR_SESSION,
@@ -325,7 +389,8 @@ class TestExcSessionNull(BaseTestCase):
     def testGetNthPset(self):
         self.assertRaisesMPI(
             MPI.ERR_SESSION,
-            MPI.SESSION_NULL.Get_nth_pset, 0,
+            MPI.SESSION_NULL.Get_nth_pset,
+            0,
         )
 
     def testGetInfo(self):
@@ -337,13 +402,15 @@ class TestExcSessionNull(BaseTestCase):
     def testGetPsetInfo(self):
         self.assertRaisesMPI(
             MPI.ERR_SESSION,
-            MPI.SESSION_NULL.Get_pset_info, "mpi://SELF",
+            MPI.SESSION_NULL.Get_pset_info,
+            "mpi://SELF",
         )
 
     def testCreateGroup(self):
         self.assertRaisesMPI(
             MPI.ERR_SESSION,
-            MPI.SESSION_NULL.Create_group, "mpi://SELF",
+            MPI.SESSION_NULL.Create_group,
+            "mpi://SELF",
         )
 
     def testGetErrhandler(self):
@@ -355,12 +422,13 @@ class TestExcSessionNull(BaseTestCase):
     def testSetErrhandler(self):
         self.assertRaisesMPI(
             MPI.ERR_SESSION,
-            MPI.SESSION_NULL.Set_errhandler, MPI.ERRORS_RETURN,
+            MPI.SESSION_NULL.Set_errhandler,
+            MPI.ERRORS_RETURN,
         )
 
 
 class TestExcSession(BaseTestCase):
-
+    #
     def setUp(self):
         super().setUp()
         self.SESSION = MPI.Session.Init()
@@ -374,39 +442,44 @@ class TestExcSession(BaseTestCase):
     def testGetNthPsetNeg(self):
         self.assertRaisesMPI(
             MPI.ERR_ARG,
-            self.SESSION.Get_nth_pset, -1,
+            self.SESSION.Get_nth_pset,
+            -1,
         )
 
-    @unittest.skipMPI('mpich(<4.1.0)')
+    @unittest.skipMPI("mpich(<4.1.0)")
     def testGetNthPsetPos(self):
         self.assertRaisesMPI(
             MPI.ERR_ARG,
-            self.SESSION.Get_nth_pset, self.SESSION.Get_num_psets(),
+            self.SESSION.Get_nth_pset,
+            self.SESSION.Get_num_psets(),
         )
 
     def testGetPsetInfo(self):
         self.assertRaisesMPI(
             MPI.ERR_ARG,
-            self.SESSION.Get_pset_info, "@qerty!#$",
+            self.SESSION.Get_pset_info,
+            "@qerty!#$",
         )
 
     def testCreateGroup(self):
         self.assertRaisesMPI(
             [MPI.ERR_ARG, MPI.ERR_UNSUPPORTED_OPERATION],
-            self.SESSION.Create_group, "@qerty!#$",
+            self.SESSION.Create_group,
+            "@qerty!#$",
         )
 
 
 try:
     MPI.Session.Init().Finalize()
 except NotImplementedError:
-    unittest.disable(TestExcSessionNull, 'mpi-session')
-    unittest.disable(TestExcSession, 'mpi-session')
+    unittest.disable(TestExcSessionNull, "mpi-session")
+    unittest.disable(TestExcSession, "mpi-session")
+
+# -----------------------------------------------------------------------------
 
-# ------------------------------------------------------------------------------
 
 class TestExcCommNull(BaseTestCase):
-
+    #
     ERR_COMM = MPI.ERR_COMM
 
     def testFree(self):
@@ -418,30 +491,43 @@ class TestExcCommNull(BaseTestCase):
     def testCompare(self):
         self.assertRaisesMPI(
             self.ERR_COMM,
-            MPI.Comm.Compare, MPI.COMM_NULL,  MPI.COMM_NULL,
+            MPI.Comm.Compare,
+            MPI.COMM_NULL,
+            MPI.COMM_NULL,
         )
         self.assertRaisesMPI(
             self.ERR_COMM,
-            MPI.Comm.Compare, MPI.COMM_SELF,  MPI.COMM_NULL,
+            MPI.Comm.Compare,
+            MPI.COMM_SELF,
+            MPI.COMM_NULL,
         )
         self.assertRaisesMPI(
             self.ERR_COMM,
-            MPI.Comm.Compare, MPI.COMM_WORLD, MPI.COMM_NULL,
+            MPI.Comm.Compare,
+            MPI.COMM_WORLD,
+            MPI.COMM_NULL,
         )
         self.assertRaisesMPI(
             self.ERR_COMM,
-            MPI.Comm.Compare, MPI.COMM_NULL,  MPI.COMM_SELF,
+            MPI.Comm.Compare,
+            MPI.COMM_NULL,
+            MPI.COMM_SELF,
         )
         self.assertRaisesMPI(
             self.ERR_COMM,
-            MPI.Comm.Compare, MPI.COMM_NULL,  MPI.COMM_WORLD,
+            MPI.Comm.Compare,
+            MPI.COMM_NULL,
+            MPI.COMM_WORLD,
         )
 
     def testAccessors(self):
         for method in (
-            'Get_size', 'Get_rank',
-            'Is_inter', 'Is_intra',
-            'Get_group', 'Get_topology',
+            "Get_size",
+            "Get_rank",
+            "Is_inter",
+            "Is_intra",
+            "Get_group",
+            "Get_topology",
         ):
             self.assertRaisesMPI(
                 MPI.ERR_COMM,
@@ -455,16 +541,17 @@ class TestExcCommNull(BaseTestCase):
                 MPI.COMM_NULL.Disconnect,
             )
         except NotImplementedError:
-            self.skipTest('mpi-comm-disconnect')
+            self.skipTest("mpi-comm-disconnect")
 
-    @unittest.skipMPI('openmpi(<1.4.2)')
+    @unittest.skipMPI("openmpi(<1.4.2)")
     def testGetAttr(self):
         self.assertRaisesMPI(
             MPI.ERR_COMM,
-            MPI.COMM_NULL.Get_attr, MPI.TAG_UB,
+            MPI.COMM_NULL.Get_attr,
+            MPI.TAG_UB,
         )
 
-    @unittest.skipMPI('openmpi(<1.4.1)')
+    @unittest.skipMPI("openmpi(<1.4.1)")
     def testGetErrhandler(self):
         self.assertRaisesMPI(
             [MPI.ERR_COMM, MPI.ERR_ARG],
@@ -474,7 +561,8 @@ class TestExcCommNull(BaseTestCase):
     def testSetErrhandler(self):
         self.assertRaisesMPI(
             MPI.ERR_COMM,
-            MPI.COMM_NULL.Set_errhandler, MPI.ERRORS_RETURN,
+            MPI.COMM_NULL.Set_errhandler,
+            MPI.ERRORS_RETURN,
         )
 
     def testIntraNull(self):
@@ -494,8 +582,8 @@ class TestExcCommNull(BaseTestCase):
 
 
 class TestExcComm(BaseTestCase):
-
-    @unittest.skipMPI('MPICH1')
+    #
+    @unittest.skipMPI("MPICH1")
     def testFreeSelf(self):
         errhdl = MPI.COMM_SELF.Get_errhandler()
         try:
@@ -508,7 +596,7 @@ class TestExcComm(BaseTestCase):
             MPI.COMM_SELF.Set_errhandler(errhdl)
             errhdl.Free()
 
-    @unittest.skipMPI('MPICH1')
+    @unittest.skipMPI("MPICH1")
     def testFreeWorld(self):
         self.assertRaisesMPI(
             [MPI.ERR_COMM, MPI.ERR_ARG],
@@ -518,40 +606,49 @@ class TestExcComm(BaseTestCase):
     def testKeyvalInvalid(self):
         self.assertRaisesMPI(
             [MPI.ERR_KEYVAL, MPI.ERR_OTHER],
-            MPI.COMM_WORLD.Get_attr, MPI.KEYVAL_INVALID,
+            MPI.COMM_WORLD.Get_attr,
+            MPI.KEYVAL_INVALID,
         )
 
-# ------------------------------------------------------------------------------
+
+# -----------------------------------------------------------------------------
+
 
 class TestExcWinNull(BaseTestCase):
+    #
+    ERRORS = [MPI.ERR_WIN, MPI.ERR_ARG]
+    if unittest.is_mpi("msmpi"):
+        ERRORS += [MPI.ERR_OTHER]
 
     def testFree(self):
         self.assertRaisesMPI(
-            [MPI.ERR_WIN, MPI.ERR_ARG],
+            self.ERRORS,
             MPI.WIN_NULL.Free,
         )
 
     def testGetErrhandler(self):
         self.assertRaisesMPI(
-            [MPI.ERR_WIN, MPI.ERR_ARG],
+            self.ERRORS,
             MPI.WIN_NULL.Get_errhandler,
         )
 
     def testSetErrhandler(self):
         self.assertRaisesMPI(
-            [MPI.ERR_WIN, MPI.ERR_ARG],
-            MPI.WIN_NULL.Set_errhandler, MPI.ERRORS_RETURN,
+            self.ERRORS,
+            MPI.WIN_NULL.Set_errhandler,
+            MPI.ERRORS_RETURN,
         )
 
     def testCallErrhandler(self):
         self.assertRaisesMPI(
             [MPI.ERR_WIN, MPI.ERR_ARG],
-            MPI.WIN_NULL.Call_errhandler, 0,
+            MPI.WIN_NULL.Call_errhandler,
+            0,
         )
 
 
 class TestExcWin(BaseTestCase):
-
+    #
     def setUp(self):
         super().setUp()
         self.WIN = MPI.Win.Create(None, 1, MPI.INFO_NULL, MPI.COMM_SELF)
@@ -565,19 +662,22 @@ class TestExcWin(BaseTestCase):
     def testKeyvalInvalid(self):
         self.assertRaisesMPI(
             [MPI.ERR_KEYVAL, MPI.ERR_OTHER],
-            self.WIN.Get_attr, MPI.KEYVAL_INVALID
+            self.WIN.Get_attr,
+            MPI.KEYVAL_INVALID,
         )
 
+
 try:
     MPI.Win.Create(None, 1, MPI.INFO_NULL, MPI.COMM_SELF).Free()
 except (NotImplementedError, MPI.Exception):
-    unittest.disable(TestExcWin, 'mpi-win')
-    unittest.disable(TestExcWinNull, 'mpi-win')
+    unittest.disable(TestExcWin, "mpi-win")
+    unittest.disable(TestExcWinNull, "mpi-win")
+
+# -----------------------------------------------------------------------------
 
-# ------------------------------------------------------------------------------
 
 class TestExcErrhandlerNull(BaseTestCase):
-
+    #
     def testFree(self):
         self.assertRaisesMPI(
             [MPI.ERR_ERRHANDLER, MPI.ERR_ARG],
@@ -588,7 +688,7 @@ class TestExcErrhandlerNull(BaseTestCase):
         self.assertRaisesMPI(
             [MPI.ERR_ERRHANDLER, MPI.ERR_ARG],
             MPI.COMM_SELF.Set_errhandler,
-            MPI.ERRHANDLER_NULL
+            MPI.ERRHANDLER_NULL,
         )
 
     def testCommWorldSetErrhandler(self):
@@ -598,12 +698,15 @@ class TestExcErrhandlerNull(BaseTestCase):
             MPI.ERRHANDLER_NULL,
         )
 
+
 class TestExcErrhandler(BaseTestCase):
+    #
     pass
 
-# ------------------------------------------------------------------------------
 
-if __name__ == '__main__':
+# -----------------------------------------------------------------------------
+
+if __name__ == "__main__":
     unittest.main()
 
-# ------------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
