@@ -1,9 +1,10 @@
-from mpi4py import MPI
 import mpiunittest as unittest
 
+from mpi4py import MPI
+
 
 class TestMemory(unittest.TestCase):
-
+    #
     def testMemory1(self):
         for size in range(0, 10000, 100):
             try:
@@ -11,7 +12,7 @@ class TestMemory(unittest.TestCase):
                 self.assertEqual(len(mem1), size)
                 MPI.Free_mem(mem1)
             except NotImplementedError:
-                self.skipTest('mpi-alloc_mem')
+                self.skipTest("mpi-alloc_mem")
 
     def testMemory2(self):
         for size in range(0, 10000, 100):
@@ -20,8 +21,8 @@ class TestMemory(unittest.TestCase):
                 self.assertEqual(len(mem2), size)
                 MPI.Free_mem(mem2)
             except NotImplementedError:
-                self.skipTest('mpi-alloc_mem')
+                self.skipTest("mpi-alloc_mem")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
